Authentication
==============

Using Artifactory,
MinIO or S3
as backend
might require authentication.
For more information,
see :class:`audbackend.backend.Artifactory`
and :class:`audbackend.backend.Minio` (for MinIO and S3).
